{% for toc_item in page.toc %}
  {% if nav_item.title != toc_item.title %}
    <li class="toctree-l{{ navlevel + 1 }}"><a href="{{ toc_item.url }}">{{ toc_item.title }}</a></li>
  {% endif %}
  {% if toc_item.children %}
    <ul class="{% if not nav_item.active%} submenu-toc{%endif%}">
    {% for toc__item in toc_item.children %}
        <li class="toctree-l{{ navlevel + 2 }}{% if navlevel > 1%} toc-item{%endif%}" >
          <a class="toctree-l{{ navlevel + 2 }}" href="{{ toc__item.url }}">{{ toc__item.title }}</a>
        </li>
    {% endfor %}
    </ul>
  {% endif %}
{% endfor %}
